@@ -3,7 +3,7 @@
   intern.h -
 
   $Author: knu $
-  $Date: 2007-02-15 11:52:43 +0900 (Thu, 15 Feb 2007) $
+  $Date: 2008-04-19 20:45:39 +0900 (Sat, 19 Apr 2008) $
   created at: Thu Jun 10 14:22:17 JST 1993
 
   Copyright (C) 1993-2003 Yukihiro Matsumoto
@@ -114,6 +114,7 @@ VALUE rb_mod_ancestors _((VALUE));
 VALUE rb_class_instance_methods _((int, VALUE*, VALUE));
 VALUE rb_class_public_instance_methods _((int, VALUE*, VALUE));
 VALUE rb_class_protected_instance_methods _((int, VALUE*, VALUE));
+VALUE rb_big_rshift(VALUE, VALUE);
 VALUE rb_class_private_instance_methods _((int, VALUE*, VALUE));
 VALUE rb_obj_singleton_methods _((int, VALUE*, VALUE));
 void rb_define_method_id _((VALUE, ID, VALUE (*)(ANYARGS), int));
@@ -127,6 +128,14 @@ VALUE rb_singleton_class _((VALUE));
 int rb_cmpint _((VALUE, VALUE, VALUE));
 NORETURN(void rb_cmperr _((VALUE, VALUE)));
 /* enum.c */
+VALUE rb_block_call _((VALUE, ID, int, VALUE*, VALUE (*)(ANYARGS), VALUE));
+/* enumerator.c */
+VALUE rb_enumeratorize _((VALUE, VALUE, int, VALUE *));
+#define RETURN_ENUMERATOR(obj, argc, argv) do {				\
+	if (!rb_block_given_p())					\
+	    return rb_enumeratorize(obj, ID2SYM(rb_frame_last_func()),	\
+				    argc, argv);			\
+    } while (0)
 /* error.c */
 RUBY_EXTERN int ruby_nerrs;
 VALUE rb_exc_new _((VALUE, const char*, long));
@@ -185,6 +194,8 @@ VALUE rb_class_new_instance _((int, VALUE*, VALUE));
 VALUE rb_block_proc _((void));
 VALUE rb_f_lambda _((void));
 VALUE rb_proc_new _((VALUE (*)(ANYARGS/* VALUE yieldarg[, VALUE procarg] */), VALUE));
+VALUE rb_proc_call _((VALUE, VALUE));
+VALUE rb_obj_method _((VALUE, VALUE));
 VALUE rb_protect _((VALUE (*)(VALUE), VALUE, int*));
 void rb_set_end_proc _((void (*)(VALUE), VALUE));
 void rb_mark_end_proc _((void));
@@ -206,12 +217,14 @@ void rb_thread_sleep _((int));
 void rb_thread_sleep_forever _((void));
 VALUE rb_thread_stop _((void));
 VALUE rb_thread_wakeup _((VALUE));
+VALUE rb_thread_wakeup_alive _((VALUE));
 VALUE rb_thread_run _((VALUE));
 VALUE rb_thread_kill _((VALUE));
+VALUE rb_thread_alive_p _((VALUE));
 VALUE rb_thread_create _((VALUE (*)(ANYARGS), void*));
 void rb_thread_interrupt _((void));
 void rb_thread_trap_eval _((VALUE, int, int));
-void rb_thread_signal_raise _((char*));
+void rb_thread_signal_raise _((int));
 void rb_thread_signal_exit _((void));
 int rb_thread_select _((int, fd_set *, fd_set *, fd_set *, struct timeval *));
 void rb_thread_wait_for _((struct timeval));
@@ -220,6 +233,7 @@ VALUE rb_thread_main _((void));
 VALUE rb_thread_local_aref _((VALUE, ID));
 VALUE rb_thread_local_aset _((VALUE, ID, VALUE));
 void rb_thread_atfork _((void));
+VALUE rb_exec_recursive _((VALUE(*)(VALUE, VALUE, int),VALUE,VALUE));
 VALUE rb_funcall_rescue __((VALUE, ID, int, ...));
 /* file.c */
 VALUE rb_file_s_expand_path _((int, VALUE *));
@@ -257,6 +271,7 @@ VALUE rb_hash _((VALUE));
 VALUE rb_hash_new _((void));
 VALUE rb_hash_freeze _((VALUE));
 VALUE rb_hash_aref _((VALUE, VALUE));
+VALUE rb_hash_lookup _((VALUE, VALUE));
 VALUE rb_hash_aset _((VALUE, VALUE, VALUE));
 VALUE rb_hash_delete_if _((VALUE));
 VALUE rb_hash_delete _((VALUE,VALUE));
@@ -316,6 +331,7 @@ VALUE rb_class_real _((VALUE));
 VALUE rb_class_inherited_p _((VALUE, VALUE));
 VALUE rb_convert_type _((VALUE,int,const char*,const char*));
 VALUE rb_check_convert_type _((VALUE,int,const char*,const char*));
+VALUE rb_check_to_integer _((VALUE, const char *));
 VALUE rb_to_int _((VALUE));
 VALUE rb_Integer _((VALUE));
 VALUE rb_Float _((VALUE));
@@ -355,6 +371,9 @@ VALUE rb_detach_process _((int));
 VALUE rb_range_new _((VALUE, VALUE, int));
 VALUE rb_range_beg_len _((VALUE, long*, long*, long, int));
 VALUE rb_length_by_each _((VALUE));
+/* random.c */
+unsigned long rb_genrand_int32(void);
+double rb_genrand_real(void);
 /* re.c */
 int rb_memcmp _((const void*,const void*,long));
 int rb_memcicmp _((const void*,const void*,long));
@@ -394,6 +413,7 @@ void posix_signal _((int, RETSIGTYPE (*)(int)));
 void rb_trap_exit _((void));
 void rb_trap_exec _((void));
 const char *ruby_signal_name _((int));
+void ruby_default_signal _((int));
 /* sprintf.c */
 VALUE rb_f_sprintf _((int, VALUE*));
 /* string.c */
@@ -406,6 +426,7 @@ VALUE rb_tainted_str_new _((const char*, long));
 VALUE rb_tainted_str_new2 _((const char*));
 VALUE rb_str_buf_new _((long));
 VALUE rb_str_buf_new2 _((const char*));
+VALUE rb_str_tmp_new _((long));
 VALUE rb_str_buf_append _((VALUE, VALUE));
 VALUE rb_str_buf_cat _((VALUE, const char*, long));
 VALUE rb_str_buf_cat2 _((VALUE, const char*));
@@ -420,6 +441,7 @@ VALUE rb_str_times _((VALUE, VALUE));
 VALUE rb_str_substr _((VALUE, long, long));
 void rb_str_modify _((VALUE));
 VALUE rb_str_freeze _((VALUE));
+void rb_str_set_len _((VALUE, long));
 VALUE rb_str_resize _((VALUE, long));
 VALUE rb_str_cat _((VALUE, const char*, long));
 VALUE rb_str_cat2 _((VALUE, const char*));
