@@ -2,8 +2,8 @@
 
   object.c -
 
-  $Author: shyouhei $
-  $Date: 2007-02-13 08:01:19 +0900 (Tue, 13 Feb 2007) $
+  $Author: knu $
+  $Date: 2008-04-20 18:04:50 +0900 (Sun, 20 Apr 2008) $
   created at: Thu Jul 15 12:01:24 JST 1993
 
   Copyright (C) 1993-2003 Yukihiro Matsumoto
@@ -494,6 +494,30 @@ rb_obj_is_kind_of(obj, c)
 }
 
 
+/*
+ *  call-seq:
+ *     obj.tap{|x|...}    => obj
+ *  
+ *  Yields <code>x</code> to the block, and then returns <code>x</code>.
+ *  The primary purpose of this method is to "tap into" a method chain,
+ *  in order to perform operations on intermediate results within the chain.
+ *
+ *	(1..10)                .tap {|x| puts "original: #{x.inspect}"}
+ *	  .to_a                .tap {|x| puts "array: #{x.inspect}"}
+ *	  .select {|x| x%2==0} .tap {|x| puts "evens: #{x.inspect}"}
+ *	  .map { |x| x*x }     .tap {|x| puts "squares: #{x.inspect}"}
+ *
+ */
+
+VALUE
+rb_obj_tap(obj)
+    VALUE obj;
+{
+    rb_yield(obj);
+    return obj;
+}
+
+
 /*
  * Document-method: inherited
  *
@@ -839,28 +863,6 @@ nil_inspect(obj)
     return rb_str_new2("nil");
 }
 
-#ifdef NIL_PLUS
-static VALUE
-nil_plus(x, y)
-    VALUE x, y;
-{
-    switch (TYPE(y)) {
-      case T_NIL:
-      case T_FIXNUM:
-      case T_FLOAT:
-      case T_BIGNUM:
-      case T_STRING:
-      case T_ARRAY:
-	return y;
-      default:
-	rb_raise(rb_eTypeError, "tried to add %s(%s) to nil",
-		 RSTRING(rb_inspect(y))->ptr,
-		 rb_obj_classname(y));
-    }
-    /* not reached */
-}
-#endif
-
 static VALUE
 main_to_s(obj)
     VALUE obj;
@@ -1966,10 +1968,12 @@ rb_obj_public_methods(argc, argv, obj)
 /*
  *  call-seq:
  *     obj.instance_variable_get(symbol)    => obj
- *  
- *  Returns the value of the given instance variable (or throws a
- *  <code>NameError</code> exception). The <code>@</code> part of the
- *  variable name should be included for regular instance variables
+ *
+ *  Returns the value of the given instance variable, or nil if the
+ *  instance variable is not set. The <code>@</code> part of the
+ *  variable name should be included for regular instance
+ *  variables. Throws a <code>NameError</code> exception if the
+ *  supplied symbol is not valid as an instance variable name.
  *     
  *     class Fred
  *       def initialize(p1, p2)
@@ -2219,6 +2223,19 @@ rb_to_integer(val, method)
     return v;
 }
 
+VALUE
+rb_check_to_integer(VALUE val, const char *method)
+{
+    VALUE v;
+
+    if (FIXNUM_P(val)) return val;
+    v = convert_type(val, "Integer", method, Qfalse);
+    if (!rb_obj_is_kind_of(v, rb_cInteger)) {
+	return Qnil;
+    }
+    return v;
+}
+
 VALUE
 rb_to_int(val)
     VALUE val;
@@ -2691,6 +2708,7 @@ Init_Object()
     rb_define_method(rb_mKernel, "instance_of?", rb_obj_is_instance_of, 1);
     rb_define_method(rb_mKernel, "kind_of?", rb_obj_is_kind_of, 1);
     rb_define_method(rb_mKernel, "is_a?", rb_obj_is_kind_of, 1);
+    rb_define_method(rb_mKernel, "tap", rb_obj_tap, 0);
 
     rb_define_private_method(rb_mKernel, "singleton_method_added", rb_obj_dummy, 1);
     rb_define_private_method(rb_mKernel, "singleton_method_removed", rb_obj_dummy, 1);
